// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef KACCOUNTS_VERSION_H
#define KACCOUNTS_VERSION_H

#define KACCOUNTS_VERSION_STRING "26.04.1"
#define KACCOUNTS_VERSION_MAJOR 26
#define KACCOUNTS_VERSION_MINOR 4
#define KACCOUNTS_VERSION_PATCH 1
#define KACCOUNTS_VERSION ((26<<16)|(4<<8)|(1))

#endif
